==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserLifecycleAttributePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserLifecycleAttributePolicyRuleCondition
 */
@JsonPropertyOrder({ UserLifecycleAttributePolicyRuleCondition.JSON_PROPERTY_ATTRIBUTE_NAME,
        UserLifecycleAttributePolicyRuleCondition.JSON_PROPERTY_MATCHING_VALUE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserLifecycleAttributePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTE_NAME = "attributeName";
    private String attributeName;

    public static final String JSON_PROPERTY_MATCHING_VALUE = "matchingValue";
    private String matchingValue;

    public UserLifecycleAttributePolicyRuleCondition() {
    }

    public UserLifecycleAttributePolicyRuleCondition attributeName(String attributeName) {

        this.attributeName = attributeName;
        return this;
    }

    /**
     * Get attributeName
     *
     * @return attributeName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAttributeName() {
        return attributeName;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public UserLifecycleAttributePolicyRuleCondition matchingValue(String matchingValue) {

        this.matchingValue = matchingValue;
        return this;
    }

    /**
     * Get matchingValue
     *
     * @return matchingValue
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MATCHING_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMatchingValue() {
        return matchingValue;
    }

    @JsonProperty(JSON_PROPERTY_MATCHING_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMatchingValue(String matchingValue) {
        this.matchingValue = matchingValue;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserLifecycleAttributePolicyRuleCondition userLifecycleAttributePolicyRuleCondition = (UserLifecycleAttributePolicyRuleCondition) o;
        return Objects.equals(this.attributeName, userLifecycleAttributePolicyRuleCondition.attributeName)
                && Objects.equals(this.matchingValue, userLifecycleAttributePolicyRuleCondition.matchingValue);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributeName, matchingValue);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserLifecycleAttributePolicyRuleCondition {\n");
        sb.append("    attributeName: ").append(toIndentedString(attributeName)).append("\n");
        sb.append("    matchingValue: ").append(toIndentedString(matchingValue)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/UserLifecycleAttributePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserLifecycleAttributePolicyRuleCondition
 */
@JsonPropertyOrder({ UserLifecycleAttributePolicyRuleCondition.JSON_PROPERTY_ATTRIBUTE_NAME,
        UserLifecycleAttributePolicyRuleCondition.JSON_PROPERTY_MATCHING_VALUE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class UserLifecycleAttributePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTE_NAME = "attributeName";
    private String attributeName;

    public static final String JSON_PROPERTY_MATCHING_VALUE = "matchingValue";
    private String matchingValue;

    public UserLifecycleAttributePolicyRuleCondition() {
    }

    public UserLifecycleAttributePolicyRuleCondition attributeName(String attributeName) {

        this.attributeName = attributeName;
        return this;
    }

    /**
     * Get attributeName
     *
     * @return attributeName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAttributeName() {
        return attributeName;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTE_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public UserLifecycleAttributePolicyRuleCondition matchingValue(String matchingValue) {

        this.matchingValue = matchingValue;
        return this;
    }

    /**
     * Get matchingValue
     *
     * @return matchingValue
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MATCHING_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMatchingValue() {
        return matchingValue;
    }

    @JsonProperty(JSON_PROPERTY_MATCHING_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMatchingValue(String matchingValue) {
        this.matchingValue = matchingValue;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserLifecycleAttributePolicyRuleCondition userLifecycleAttributePolicyRuleCondition = (UserLifecycleAttributePolicyRuleCondition) o;
        return Objects.equals(this.attributeName, userLifecycleAttributePolicyRuleCondition.attributeName)
                && Objects.equals(this.matchingValue, userLifecycleAttributePolicyRuleCondition.matchingValue);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributeName, matchingValue);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserLifecycleAttributePolicyRuleCondition {\n");
        sb.append("    attributeName: ").append(toIndentedString(attributeName)).append("\n");
        sb.append("    matchingValue: ").append(toIndentedString(matchingValue)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
